@@ -1,5 +1,6 @@
 import subprocess
 import os
+from . import paths
 
 def HomeDirectory():
     return os.path.expanduser('~')
@@ -30,3 +31,13 @@ def ip_address(interface='en0'):
     ip = ip[0].removesuffix('\n')
     return ip
 
+def hostname():
+    import socket
+    return socket.gethostname()
+
+def remove(file):
+    command(['rm', '-rf', file])
+
+
+if __name__ == '__main__':
+    print(ip_address())
\ No newline at end of file
