@@ -1,7 +1,14 @@
 import os
 import shutil
+import subprocess
 
 
+def _command(args: list):
+    sub = subprocess.Popen(args, stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT)
+    sub.wait()
+    sub.kill()
+    sub.terminate()
+
 def _decoder(string_path: str) -> str:
     if string_path.startswith('~'):
         string_path = join(os.path.expanduser('~'), string_path.split('~', 1)[1])
@@ -110,22 +117,8 @@ def join(path1: str, path2: str):
     path = path1 + path2
     return path
 
-def remove_file(file, is_directory=False):
-
-    if not file_exists(file) or directory_exists(file):
-        raise FileNotFoundError('Unable to find file')
-
-    if directory_exists(file) != is_directory:
-        raise IsADirectoryError('To remove a directory set is_directory=True')
-
-    if not is_directory:
-        os.remove(file)
-    else:
-        try:
-            os.removedirs(file)
-        except OSError:
-            from utils.system import command
-            command(['rm', '-rf', file])
+def remove_file(file, blank):
+    _command(['rm', '-rf', file])
 
 
 class Path:
